==> jupyterlab-filesystem-access-0.4.0.tar.gz: jupyterlab-filesystem-access-0.4.0/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.4.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.3.0...57ecfc93de1c9b2ae470e05c883a69b10b023fef))

### Enhancements made

- Add support for base64 types [#20](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/20) ([@martinRenou](https://github.com/martinRenou))

### Documentation improvements

- Update README with docs and lite links [#29](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/29) ([@martinRenou](https://github.com/martinRenou))
- Update documentation title [#28](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/28) ([@jtpio](https://github.com/jtpio))
- Add docs [#27](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/27) ([@martinRenou](https://github.com/martinRenou))
- Update links to point to the new repo [#25](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/25) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Disable rename and copy menus [#23](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/23) ([@martinRenou](https://github.com/martinRenou))
- Implement delete [#15](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/15) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-12&to=2022-04-15&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-12..2022-04-15&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-12..2022-04-15&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.2.0...8e56ca1c3ee5e81f725cf8b57198c5b6d301c935))

### Merged PRs

- Implement newUntitled [#14](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/14) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-11&to=2022-04-12&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-11..2022-04-12&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.1.1...b776fa853b8e6a3a6a3990278a9987f56f6e77a5))

### Enhancements made

- Add support opening subdirs [#11](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/11) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-09&to=2022-04-11&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-09..2022-04-11&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-09..2022-04-11&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.1.0...3d9774618956b282ebb9f3498c6e0f3731dea86d))

### Bugs fixed

- Fix saving Notebooks [#9](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/9) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-09&to=2022-04-09&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-09..2022-04-09&type=Issues)

## 0.1.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/cec8cbbce5042c8f7d6dce07265fba5a5317c8df...bbc9d3597d0694178d96c00268ff6d501b6a1268))

### Enhancements made

- Basic support for saving a file [#5](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/5) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Reset version [#7](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/7) ([@jtpio](https://github.com/jtpio))
- Rename to `jupyterlab-filesystem-access` [#6](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/6) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add disclaimer to README.md [#4](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-08&to=2022-04-09&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-08..2022-04-09&type=Issues)

==> jupyterlab-filesystem-access-0.5.2.tar.gz: jupyterlab-filesystem-access-0.5.2/CHANGELOG.md <==
# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.5.2

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.5.1...aed82cae404ab142796351b2b2048f4d7dfe162d))

### Bugs fixed

- Emit fileChanged after rename [#41](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/41) ([@hbcarlos](https://github.com/hbcarlos))

### Other merged PRs

- Move the lint check to a separate workflow [#42](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/42) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-06-30&to=2022-08-02&type=c))

[@hbcarlos](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3Ahbcarlos+updated%3A2022-06-30..2022-08-02&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-06-30..2022-08-02&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-06-30..2022-08-02&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.5.1

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.5.0...5f9ffde9a55c686ac1c4df3ec70ad4edc3ba7c4f))

### Bugs fixed

- Fix README reading [#38](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/38) ([@martinRenou](https://github.com/martinRenou))
- Remove settings registry initilization [#36](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/36) ([@martinRenou](https://github.com/martinRenou))

### Maintenance and upkeep improvements

- Run CI on Windows + Use micromamba [#37](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/37) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-06-15&to=2022-06-30&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-06-15..2022-06-30&type=Issues)

## 0.5.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.4.0...bc5c2068f6b6a12511a1f46f53178b5ba1e9b158))

### Enhancements made

- Implement rename and copy [#34](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/34) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-15&to=2022-06-15&type=c))

[@fcollonval](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3Afcollonval+updated%3A2022-04-15..2022-06-15&type=Issues) | [@jtpio](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-15..2022-06-15&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-15..2022-06-15&type=Issues)

## 0.4.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.3.0...57ecfc93de1c9b2ae470e05c883a69b10b023fef))

### Enhancements made

- Add support for base64 types [#20](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/20) ([@martinRenou](https://github.com/martinRenou))

### Documentation improvements

- Update README with docs and lite links [#29](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/29) ([@martinRenou](https://github.com/martinRenou))
- Update documentation title [#28](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/28) ([@jtpio](https://github.com/jtpio))
- Add docs [#27](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/27) ([@martinRenou](https://github.com/martinRenou))
- Update links to point to the new repo [#25](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/25) ([@jtpio](https://github.com/jtpio))

### Other merged PRs

- Disable rename and copy menus [#23](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/23) ([@martinRenou](https://github.com/martinRenou))
- Implement delete [#15](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/15) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-12&to=2022-04-15&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-12..2022-04-15&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajupyterlab-contrib%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-12..2022-04-15&type=Issues)

## 0.3.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.2.0...8e56ca1c3ee5e81f725cf8b57198c5b6d301c935))

### Merged PRs

- Implement newUntitled [#14](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/14) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-11&to=2022-04-12&type=c))

[@martinRenou](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-11..2022-04-12&type=Issues)

## 0.2.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.1.1...b776fa853b8e6a3a6a3990278a9987f56f6e77a5))

### Enhancements made

- Add support opening subdirs [#11](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/11) ([@martinRenou](https://github.com/martinRenou))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-09&to=2022-04-11&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-09..2022-04-11&type=Issues) | [@martinRenou](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3AmartinRenou+updated%3A2022-04-09..2022-04-11&type=Issues)

## 0.1.1

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/v0.1.0...3d9774618956b282ebb9f3498c6e0f3731dea86d))

### Bugs fixed

- Fix saving Notebooks [#9](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/9) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-09&to=2022-04-09&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-09..2022-04-09&type=Issues)

## 0.1.0

([Full Changelog](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/compare/cec8cbbce5042c8f7d6dce07265fba5a5317c8df...bbc9d3597d0694178d96c00268ff6d501b6a1268))

### Enhancements made

- Basic support for saving a file [#5](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/5) ([@jtpio](https://github.com/jtpio))

### Maintenance and upkeep improvements

- Reset version [#7](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/7) ([@jtpio](https://github.com/jtpio))
- Rename to `jupyterlab-filesystem-access` [#6](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/6) ([@jtpio](https://github.com/jtpio))

### Documentation improvements

- Add disclaimer to README.md [#4](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/pull/4) ([@jtpio](https://github.com/jtpio))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/jupyterlab-contrib/jupyterlab-filesystem-access/graphs/contributors?from=2022-04-08&to=2022-04-09&type=c))

[@jtpio](https://github.com/search?q=repo%3Ajtpio%2Fjupyterlab-filesystem-access+involves%3Ajtpio+updated%3A2022-04-08..2022-04-09&type=Issues)
